summaryrefslogtreecommitdiff
path: root/Applications/Taskbar/TaskbarWindow.cpp
diff options
context:
space:
mode:
authorAndreas Kling <kling@serenityos.org>2020-02-02 12:34:39 +0100
committerAndreas Kling <kling@serenityos.org>2020-02-02 15:15:30 +0100
commit2d39da5405a4527e91e853ddb1e56a539c96c6c1 (patch)
tree342f5d553c844f05b550510de27d5b7c937daf90 /Applications/Taskbar/TaskbarWindow.cpp
parentb7e3810b5c3d7e52217e70eed61132d9f670648d (diff)
downloadserenity-2d39da5405a4527e91e853ddb1e56a539c96c6c1.zip
LibCore: Put all classes in the Core namespace and remove the leading C
I've been wanting to do this for a long time. It's time we start being consistent about how this stuff works. The new convention is: - "LibFoo" is a userspace library that provides the "Foo" namespace. That's it :^) This was pretty tedious to convert and I didn't even start on LibGUI yet. But it's coming up next.
Diffstat (limited to 'Applications/Taskbar/TaskbarWindow.cpp')
-rw-r--r--Applications/Taskbar/TaskbarWindow.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Applications/Taskbar/TaskbarWindow.cpp b/Applications/Taskbar/TaskbarWindow.cpp
index 558770f732..3492a12fba 100644
--- a/Applications/Taskbar/TaskbarWindow.cpp
+++ b/Applications/Taskbar/TaskbarWindow.cpp
@@ -81,15 +81,15 @@ void TaskbarWindow::create_quick_launch_bar()
int total_width = 6;
bool first = true;
- auto config = CConfigFile::get_for_app("Taskbar");
+ auto config = Core::ConfigFile::get_for_app("Taskbar");
constexpr const char* quick_launch = "QuickLaunch";
// FIXME: CConfigFile does not keep the order of the entries.
for (auto& name : config->keys(quick_launch)) {
auto af_name = config->read_entry(quick_launch, name);
ASSERT(!af_name.is_null());
auto af_path = String::format("/res/apps/%s", af_name.characters());
- auto af = CConfigFile::open(af_path);
+ auto af = Core::ConfigFile::open(af_path);
auto app_executable = af->read_entry("App", "Executable");
auto app_icon_path = af->read_entry("Icons", "16x16");
@@ -81,15 +81,15 @@ void TaskbarWindow::create_quick_launch_bar()
constexpr const char* quick_launch = "QuickLaunch";
- // FIXME: CConfigFile does not keep the order of the entries.
+ // FIXME: Core::ConfigFile does not keep the order of the entries.
for (auto& name : config->keys(quick_launch)) {
auto af_name = config->read_entry(quick_launch, name);